Lean class

Inheritance

Constructors

Lean.authorizeConsent({Key? key, required String appToken, required String? customerId, required String? consentId, required String? failRedirectUrl, required String? successRedirectUrl, LeanCallback? callback, String? accessToken, Map<String, String>? customization, LeanActionCancelled? actionCancelled, bool isSandbox = true, bool showLogs = false, String version = 'latest', String env = 'production', LeanCountry country = LeanCountry.ae, LeanLanguage language = LeanLanguage.en, String? bankIdentifier, String? accountId, RiskDetails? riskDetails, bool? allowPaymentSourceChange, String? destinationAlias, String? destinationAvatar})
const
Lean.captureRedirect({Key? key, required String appToken, required String? customerId, LeanCallback? callback, String? accessToken, Map<String, String>? customization, LeanActionCancelled? actionCancelled, bool isSandbox = true, bool showLogs = false, String version = 'latest', String env = 'production', LeanCountry country = LeanCountry.ae, LeanLanguage language = LeanLanguage.en, String? consentAttemptId, String? granularStatusCode, String? statusAdditionalInfo})
const
Lean.checkout({Key? key, required String appToken, required String? paymentIntentId, required String? failRedirectUrl, required String? successRedirectUrl, LeanCallback? callback, String? accessToken, Map<String, String>? customization, LeanActionCancelled? actionCancelled, bool isSandbox = true, bool showLogs = false, String version = 'latest', String env = 'production', LeanCountry country = LeanCountry.ae, LeanLanguage language = LeanLanguage.en, String? customerName, String? bankIdentifier, String? accountId, RiskDetails? riskDetails, bool? allowPaymentSourceChange})
const
Lean.connect({Key? key, required String appToken, required String? customerId, required List<LeanPermissions>? permissions, LeanCallback? callback, Map<String, String>? customization, LeanActionCancelled? actionCancelled, bool isSandbox = true, bool showLogs = false, String version = 'latest', String env = 'production', LeanCountry country = LeanCountry.ae, LeanLanguage language = LeanLanguage.en, String? accessTo, String? accessFrom, String? accessToken, String? bankIdentifier, String? failRedirectUrl, String? successRedirectUrl, String? paymentDestinationId, String? customerMetadata, bool? showConsentExplanation, String? destinationAlias, String? destinationAvatar})
const
Lean.createBeneficiary({Key? key, required String appToken, required String? customerId, LeanCallback? callback, String? accessToken, Map<String, String>? customization, LeanActionCancelled? actionCancelled, bool isSandbox = true, bool showLogs = false, String version = 'latest', String env = 'production', LeanCountry country = LeanCountry.ae, LeanLanguage language = LeanLanguage.en, String? paymentSourceId, String? failRedirectUrl, String? successRedirectUrl, String? paymentDestinationId, String? destinationAlias, String? destinationAvatar})
const
Lean.createPaymentSource({Key? key, required String appToken, required String? customerId, LeanCallback? callback, String? accessToken, Map<String, String>? customization, LeanActionCancelled? actionCancelled, bool isSandbox = true, bool showLogs = false, String version = 'latest', String env = 'production', LeanCountry country = LeanCountry.ae, LeanLanguage language = LeanLanguage.en, String? bankIdentifier, String? failRedirectUrl, String? paymentSourceId, String? successRedirectUrl, String? paymentDestinationId, String? destinationAlias, String? destinationAvatar})
const
Lean.manageConsents({Key? key, required String appToken, required String? customerId, LeanCallback? callback, String? accessToken, Map<String, String>? customization, LeanActionCancelled? actionCancelled, bool isSandbox = true, bool showLogs = false, String version = 'latest', String env = 'production', LeanCountry country = LeanCountry.ae, LeanLanguage language = LeanLanguage.en})
const
Lean.pay({Key? key, required String appToken, required String? paymentIntentId, LeanCallback? callback, String? accessToken, Map<String, String>? customization, LeanActionCancelled? actionCancelled, bool isSandbox = true, bool showLogs = false, String version = 'latest', String env = 'production', LeanCountry country = LeanCountry.ae, LeanLanguage language = LeanLanguage.en, String? accountId, String? bankIdentifier, bool? showBalances, bool? allowPaymentSourceChange, String? failRedirectUrl, String? successRedirectUrl, RiskDetails? riskDetails, String? destinationAlias, String? destinationAvatar})
const
Lean.reconnect({Key? key, required String appToken, required String? reconnectId, LeanCallback? callback, String? accessToken, Map<String, String>? customization, LeanActionCancelled? actionCancelled, bool isSandbox = true, bool showLogs = false, String version = 'latest', String env = 'production', LeanCountry country = LeanCountry.ae, LeanLanguage language = LeanLanguage.en, String? customerMetadata, String? destinationAlias, String? destinationAvatar})
const
Lean.updatePaymentSource({Key? key, required String appToken, required String? customerId, LeanCallback? callback, String? accessToken, Map<String, String>? customization, LeanActionCancelled? actionCancelled, bool isSandbox = true, bool showLogs = false, String version = 'latest', String env = 'production', LeanCountry country = LeanCountry.ae, LeanLanguage language = LeanLanguage.en, String? paymentSourceId, String? failRedirectUrl, String? successRedirectUrl, String? paymentDestinationId, String? destinationAlias, String? destinationAvatar})
const
Lean.verifyAddress({Key? key, required String appToken, required String? customerId, required String? customerName, required List<LeanPermissions>? permissions, LeanCallback? callback, String? accessToken, Map<String, String>? customization, LeanActionCancelled? actionCancelled, bool isSandbox = true, bool showLogs = false, String version = 'latest', String env = 'production', LeanCountry country = LeanCountry.ae, LeanLanguage language = LeanLanguage.en, String? destinationAlias, String? destinationAvatar})
const

Properties

accessFrom String?
final
accessTo String?
final
accessToken String?
final
accountId String?
final
actionCancelled LeanActionCancelled?
final
allowPaymentSourceChange bool?
final
appToken String
final
bankIdentifier String?
final
callback LeanCallback?
final
consentAttemptId String?
final
consentId String?
final
country LeanCountry
final
customerId String?
final
customerMetadata String?
final
customerName String?
final
customization Map<String, String>?
final
destinationAlias String?
final
destinationAvatar String?
final
env String
final
failRedirectUrl String?
final
granularStatusCode String?
final
hashCode int
The hash code for this object.
no setterinherited
initializationUrl String
final
isSandbox bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
language LeanLanguage
final
paymentDestinationId String?
final
paymentIntentId String?
final
paymentSourceId String?
final
permissions List<LeanPermissions>?
final
reconnectId String?
final
riskDetails RiskDetails?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showBalances bool?
final
showConsentExplanation bool?
final
showLogs bool
final
statusAdditionalInfo String?
final
successRedirectUrl String?
final
version String
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<Lean>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited